pub fn ordered_references(ctx: &CiteContext) -> Vec<Reference>Expand description
References ordered for the bibliography display: number order for numbered styles, definition order otherwise (the keyed list re-sorts author styles).
pub fn ordered_references(ctx: &CiteContext) -> Vec<Reference>References ordered for the bibliography display: number order for numbered styles, definition order otherwise (the keyed list re-sorts author styles).