pub fn with_active<R>(f: impl FnOnce(Option<&CiteContext>) -> R) -> RExpand description
Run f with a reference to the ambient context (if any).
pub fn with_active<R>(f: impl FnOnce(Option<&CiteContext>) -> R) -> RRun f with a reference to the ambient context (if any).