install_image_context

Function install_image_context 

pub fn install_image_context(map: HashMap<String, String>) -> ImageScope
Install map (image src → resolvable virtual file path) as the ambient image context for the current thread for the lifetime of the returned guard. The PDF renderer installs this before to_typst after registering the mapped paths with the engine’s static file resolver.